==> qtjambi-debuginfo-macos-5.15.17.jar: sources/QtJambiGui/QAccessibleStateChangeEvent_shell.cpp <==
#include "QAccessibleStateChangeEvent_shell.h"
#include <QtJambi/Cast>

void deleter_QAccessibleStateChangeEvent(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QAccessibleStateChangeEvent")
    QAccessibleStateChangeEvent *_ptr = reinterpret_cast<QAccessibleStateChangeEvent *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

QtJambiShell* QAccessibleStateChangeEvent_shell::__shell() const { return *reinterpret_cast<QtJambiShell**>( quintptr(this) + sizeof(QAccessibleStateChangeEvent_shell) ); }

jmethodID QAccessibleStateChangeEvent_shell::__shell_javaMethod(int pos) const { return QAccessibleStateChangeEvent_shell::__shell()->javaMethod(typeid(QAccessibleStateChangeEvent), pos); }

// emitting (writeShellConstructor)
QAccessibleStateChangeEvent_shell::QAccessibleStateChangeEvent_shell(QAccessibleInterface* iface0, QAccessible::State state1)
    : QAccessibleStateChangeEvent(iface0, state1)
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QAccessibleStateChangeEvent::QAccessibleStateChangeEvent_shell(QAccessibleInterface* iface0, QAccessible::State state1)", QAccessibleStateChangeEvent_shell::__shell())
    QAccessibleStateChangeEvent_shell::__shell()->constructed(typeid(QAccessibleStateChangeEvent));
}

QAccessibleStateChangeEvent_shell::QAccessibleStateChangeEvent_shell(QObject* obj0, QAccessible::State state1)
    : QAccessibleStateChangeEvent(obj0, state1)
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QAccessibleStateChangeEvent::QAccessibleStateChangeEvent_shell(QObject* obj0, QAccessible::State state1)", QAccessibleStateChangeEvent_shell::__shell())
    QAccessibleStateChangeEvent_shell::__shell()->constructed(typeid(QAccessibleStateChangeEvent));
}

// emitting (writeShellDestructor)
QAccessibleStateChangeEvent_shell::~QAccessibleStateChangeEvent_shell()
{
    QTJAMBI_IN_DESTRUCTOR_CALL("QAccessibleStateChangeEvent::~QAccessibleStateChangeEvent()", QAccessibleStateChangeEvent_shell::__shell())
    QAccessibleStateChangeEvent_shell::__shell()->destructed(typeid(QAccessibleStateChangeEvent));
}

void QAccessibleStateChangeEvent_shell::operator delete(void * ptr) noexcept {
    reinterpret_cast<QAccessibleStateChangeEvent_shell*>(ptr)->QAccessibleStateChangeEvent_shell::__shell()->tryDeleteShell(typeid(QAccessibleStateChangeEvent));
}

// emitting Virtual overrides (virtualFunctions)
QAccessibleInterface* QAccessibleStateChangeEvent_shell::accessibleInterface() const
{
    if(jmethodID method_id = __shell_javaMethod(0)){
        QTJAMBI_JAVA_METHOD_CALL("QAccessibleStateChangeEvent::", QAccessibleStateChangeEvent_shell::__shell())
        if(JniEnvironment __jni_env{200}) {
            QtJambiExceptionHandler __qj_exnhandler;
            QAccessibleInterface*  __qt_return_value = nullptr;
            QTJAMBI_TRY {
                if(jobject __java_this = QAccessibleStateChangeEvent_shell::__shell()->getJavaObjectLocalRef(__jni_env)){
                    jobject __java_return_value = __jni_env->CallObjectMethod(__java_this, method_id);
                    JavaException::check(__jni_env QTJAMBI_STACKTRACEINFO );
                    __qt_return_value = qtjambi_cast<QAccessibleInterface* >(__jni_env, __java_return_value);
                } else {
                    QAccessibleStateChangeEvent_shell::__shell()->warnForMethod("QAccessibleStateChangeEvent::");
                }
            } QTJAMBI_CATCH(const JavaException& exn){
                __qj_exnhandler.handle(__jni_env, exn, "QAccessibleStateChangeEvent::");
            } QTJAMBI_TRY_END
            return __qt_return_value;
        }else{
            return QAccessibleEvent::accessibleInterface();
        }
    }else{
        return QAccessibleEvent::accessibleInterface();
    }
}

// emitting Functions in shell class (nonVirtualShellFunctions)
// emitting Public Override Functions (publicOverrideFunctions)
// emitting Virtual Override Functions (virtualOverrideFunctions)
// emitting (writeConstructors)
// new QAccessibleStateChangeEvent(QAccessibleInterface*,QAccessible::State)
void __qt_construct_QAccessibleStateChangeEvent_0(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QAccessibleStateChangeEvent(QAccessibleInterface*,QAccessible::State)")
    jobject iface0 = __java_arguments[0].l;
    QAccessibleInterface* __qt_iface0 = qtjambi_cast<QAccessibleInterface* >(__jni_env, iface0);
    jobject state1 = __java_arguments[1].l;
    QAccessible::State __qt_state1 = qtjambi_cast<QAccessible::State >(__jni_env, state1);
    QAccessibleStateChangeEvent *__qt_this = new(__qtjambi_ptr) QAccessibleStateChangeEvent_shell(__qt_iface0, __qt_state1);
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// new QAccessibleStateChangeEvent(QObject*,QAccessible::State)
void __qt_construct_QAccessibleStateChangeEvent_1(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QAccessibleStateChangeEvent(QObject*,QAccessible::State)")
    jobject obj0 = __java_arguments[0].l;
    QObject* __qt_obj0 = qtjambi_cast<QObject* >(__jni_env, obj0);
    jobject state1 = __java_arguments[1].l;
    QAccessible::State __qt_state1 = qtjambi_cast<QAccessible::State >(__jni_env, state1);
    QAccessibleStateChangeEvent *__qt_this = new(__qtjambi_ptr) QAccessibleStateChangeEvent_shell(__qt_obj0, __qt_state1);
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// destruct QAccessibleStateChangeEvent_shell
void __qt_destruct_QAccessibleStateChangeEvent(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QAccessibleStateChangeEvent")
    reinterpret_cast<QAccessibleStateChangeEvent_shell*>(ptr)->~QAccessibleStateChangeEvent_shell();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QAccessibleStateChangeEvent::QAccessibleStateChangeEvent(QAccessibleInterface*,QAccessible::State)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QAccessibleStateChangeEvent_initialize_1native__Lio_qt_gui_QAccessibleStateChangeEvent_2Lio_qt_gui_QAccessibleInterface_2Lio_qt_gui_QAccessible_00024State_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject iface0,
 jobject state1)
{
    QTJAMBI_NATIVE_METHOD_CALL("QAccessibleStateChangeEvent::QAccessibleStateChangeEvent(QAccessibleInterface*,QAccessible::State)")
    QTJAMBI_TRY {
        jvalue arguments[2];
        arguments[0].l = iface0;
        arguments[1].l = state1;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QAccessibleStateChangeEvent_0, sizeof(QAccessibleStateChangeEvent_shell), typeid(QAccessibleStateChangeEvent), true, &deleter_QAccessibleStateChangeEvent, arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QAccessibleStateChangeEvent::QAccessibleStateChangeEvent(QObject*,QAccessible::State)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QAccessibleStateChangeEvent_initialize_1native__Lio_qt_gui_QAccessibleStateChangeEvent_2Lio_qt_core_QObject_2Lio_qt_gui_QAccessible_00024State_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject obj0,
 jobject state1)
{
    QTJAMBI_NATIVE_METHOD_CALL("QAccessibleStateChangeEvent::QAccessibleStateChangeEvent(QObject*,QAccessible::State)")
    QTJAMBI_TRY {
        jvalue arguments[2];
        arguments[0].l = obj0;
        arguments[1].l = state1;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QAccessibleStateChangeEvent_1, sizeof(QAccessibleStateChangeEvent_shell), typeid(QAccessibleStateChangeEvent), true, &deleter_QAccessibleStateChangeEvent, arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// QAccessibleStateChangeEvent::changedStates()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QAccessibleStateChangeEvent_changedStates_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QAccessibleStateChangeEvent *__qt_this = QtJambiAPI::objectFromNativeId<QAccessibleStateChangeEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QAccessibleStateChangeEvent::changedStates()const", __qt_this)
        QAccessible::State __qt_return_value = __qt_this->changedStates();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting Field accessors (writeFieldAccessors)
void QAccessibleStateChangeEvent_access::setChangedStates_cref_QAccessible_State(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID changedStates0)
{
    Q_UNUSED(__this_nativeId)
    Q_UNUSED(__jni_env)
    const QAccessible::State& __qt_changedStates0 = QtJambiAPI::valueReferenceFromNativeId<QAccessible::State>(changedStates0);
    this->QAccessibleStateChangeEvent::m_changedStates = __qt_changedStates0;
}

extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QAccessibleStateChangeEvent_setChangedStates_1native_1cref_1QAccessible_1State__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID changedStates0)
{
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QAccessibleStateChangeEvent *__qt_this = QtJambiAPI::objectFromNativeId<QAccessibleStateChangeEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        static_cast<QAccessibleStateChangeEvent_access*>(__qt_this)->setChangedStates_cref_QAccessible_State(__jni_env, __this_nativeId, changedStates0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
}

// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_QAccessibleStateChangeEvent(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerObjectTypeInfo<QAccessibleStateChangeEvent>("QAccessibleStateChangeEvent", "io/qt/gui/QAccessibleStateChangeEvent");
// BEGIN: function table
    registerFunctionInfos(typeId, {
        FunctionInfo(/* 0 */ "accessibleInterface", "()Lio/qt/gui/QAccessibleInterface;")});
    registerConstructorInfos(typeId, &__qt_destruct_QAccessibleStateChangeEvent, {
        ConstructorInfo(&__qt_construct_QAccessibleStateChangeEvent_0, "Lio/qt/gui/QAccessibleInterface;Lio/qt/gui/QAccessible$State;")
       ,ConstructorInfo(&__qt_construct_QAccessibleStateChangeEvent_1, "Lio/qt/core/QObject;Lio/qt/gui/QAccessible$State;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QAccessibleStateChangeEvent);
    registerSizeOfShell(typeId, sizeof(QAccessibleStateChangeEvent_shell));
// END: type registration

// BEGIN: polymorphic ids
    registerDefaultPolymorphyHandler<QAccessibleEvent, QAccessibleStateChangeEvent>();
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}

==> qtjambi-debuginfo-macos-5.15.19.jar: sources/QtJambiGui/QAccessibleStateChangeEvent_shell.cpp <==
#include "QAccessibleStateChangeEvent_shell.h"
#include <QtJambi/Cast>

void deleter_QAccessibleStateChangeEvent(void *ptr, bool isShell)
{
    QTJAMBI_NATIVE_METHOD_CALL("qtjambi_deleter for QAccessibleStateChangeEvent")
    QAccessibleStateChangeEvent *_ptr = reinterpret_cast<QAccessibleStateChangeEvent *>(ptr);
    if(!isShell){
        QtJambiAPI::registerNonShellDeletion(ptr);
    }
    delete _ptr;
}

QtJambiShell* QAccessibleStateChangeEvent_shell::__shell() const { return *reinterpret_cast<QtJambiShell**>( quintptr(this) + sizeof(QAccessibleStateChangeEvent_shell) ); }

jmethodID QAccessibleStateChangeEvent_shell::__shell_javaMethod(int pos) const { return QAccessibleStateChangeEvent_shell::__shell()->javaMethod(typeid(QAccessibleStateChangeEvent), pos); }

// emitting (writeShellConstructor)
QAccessibleStateChangeEvent_shell::QAccessibleStateChangeEvent_shell(QAccessibleInterface* iface0, QAccessible::State state1)
    : QAccessibleStateChangeEvent(iface0, state1)
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QAccessibleStateChangeEvent::QAccessibleStateChangeEvent_shell(QAccessibleInterface* iface0, QAccessible::State state1)", QAccessibleStateChangeEvent_shell::__shell())
    QAccessibleStateChangeEvent_shell::__shell()->constructed(typeid(QAccessibleStateChangeEvent));
}

QAccessibleStateChangeEvent_shell::QAccessibleStateChangeEvent_shell(QObject* obj0, QAccessible::State state1)
    : QAccessibleStateChangeEvent(obj0, state1)
{
    QTJAMBI_IN_CONSTRUCTOR_CALL("QAccessibleStateChangeEvent::QAccessibleStateChangeEvent_shell(QObject* obj0, QAccessible::State state1)", QAccessibleStateChangeEvent_shell::__shell())
    QAccessibleStateChangeEvent_shell::__shell()->constructed(typeid(QAccessibleStateChangeEvent));
}

// emitting (writeShellDestructor)
QAccessibleStateChangeEvent_shell::~QAccessibleStateChangeEvent_shell()
{
    QTJAMBI_IN_DESTRUCTOR_CALL("QAccessibleStateChangeEvent::~QAccessibleStateChangeEvent()", QAccessibleStateChangeEvent_shell::__shell())
    QAccessibleStateChangeEvent_shell::__shell()->destructed(typeid(QAccessibleStateChangeEvent));
}

void QAccessibleStateChangeEvent_shell::operator delete(void * ptr) noexcept {
    reinterpret_cast<QAccessibleStateChangeEvent_shell*>(ptr)->QAccessibleStateChangeEvent_shell::__shell()->tryDeleteShell(typeid(QAccessibleStateChangeEvent));
}

// emitting Virtual overrides (virtualFunctions)
QAccessibleInterface* QAccessibleStateChangeEvent_shell::accessibleInterface() const
{
    if(jmethodID method_id = __shell_javaMethod(0)){
        QTJAMBI_JAVA_METHOD_CALL("QAccessibleStateChangeEvent::", QAccessibleStateChangeEvent_shell::__shell())
        if(JniEnvironment __jni_env{200}) {
            QtJambiExceptionHandler __qj_exnhandler;
            QAccessibleInterface*  __qt_return_value = nullptr;
            QTJAMBI_TRY {
                if(jobject __java_this = QAccessibleStateChangeEvent_shell::__shell()->getJavaObjectLocalRef(__jni_env)){
                    jobject __java_return_value = __jni_env->CallObjectMethod(__java_this, method_id);
                    JavaException::check(__jni_env QTJAMBI_STACKTRACEINFO );
                    __qt_return_value = qtjambi_cast<QAccessibleInterface* >(__jni_env, __java_return_value);
                } else {
                    QAccessibleStateChangeEvent_shell::__shell()->warnForMethod("QAccessibleStateChangeEvent::");
                }
            } QTJAMBI_CATCH(const JavaException& exn){
                __qj_exnhandler.handle(__jni_env, exn, "QAccessibleStateChangeEvent::");
            } QTJAMBI_TRY_END
            return __qt_return_value;
        }else{
            return QAccessibleEvent::accessibleInterface();
        }
    }else{
        return QAccessibleEvent::accessibleInterface();
    }
}

// emitting Functions in shell class (nonVirtualShellFunctions)
// emitting Public Override Functions (publicOverrideFunctions)
// emitting Virtual Override Functions (virtualOverrideFunctions)
// emitting (writeConstructors)
// new QAccessibleStateChangeEvent(QAccessibleInterface*,QAccessible::State)
void __qt_construct_QAccessibleStateChangeEvent_QAccessibleInterface_ptr_QAccessible_State(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QAccessibleStateChangeEvent(QAccessibleInterface*,QAccessible::State)")
    jobject iface0 = __java_arguments[0].l;
    QAccessibleInterface* __qt_iface0 = qtjambi_cast<QAccessibleInterface* >(__jni_env, iface0);
    jobject state1 = __java_arguments[1].l;
    QAccessible::State __qt_state1 = qtjambi_cast<QAccessible::State >(__jni_env, state1);
    QAccessibleStateChangeEvent *__qt_this = new(__qtjambi_ptr) QAccessibleStateChangeEvent_shell(__qt_iface0, __qt_state1);
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// QAccessibleStateChangeEvent::QAccessibleStateChangeEvent(QAccessibleInterface*,QAccessible::State)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QAccessibleStateChangeEvent_initialize_1native__Lio_qt_gui_QAccessibleStateChangeEvent_2Lio_qt_gui_QAccessibleInterface_2Lio_qt_gui_QAccessible_00024State_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject iface0,
 jobject state1)
{
    QTJAMBI_NATIVE_METHOD_CALL("QAccessibleStateChangeEvent::QAccessibleStateChangeEvent(QAccessibleInterface*,QAccessible::State)")
    QTJAMBI_TRY {
        jvalue arguments[2];
        arguments[0].l = iface0;
        arguments[1].l = state1;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QAccessibleStateChangeEvent_QAccessibleInterface_ptr_QAccessible_State, sizeof(QAccessibleStateChangeEvent_shell), typeid(QAccessibleStateChangeEvent), true, &deleter_QAccessibleStateChangeEvent, arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// new QAccessibleStateChangeEvent(QObject*,QAccessible::State)
void __qt_construct_QAccessibleStateChangeEvent_QObject_ptr_QAccessible_State(void* __qtjambi_ptr, JNIEnv* __jni_env, jobject __jni_object, jvalue* __java_arguments, bool __qtjambi_is_generic)
{
    QTJAMBI_NATIVE_METHOD_CALL("construct QAccessibleStateChangeEvent(QObject*,QAccessible::State)")
    jobject obj0 = __java_arguments[0].l;
    QObject* __qt_obj0 = qtjambi_cast<QObject* >(__jni_env, obj0);
    jobject state1 = __java_arguments[1].l;
    QAccessible::State __qt_state1 = qtjambi_cast<QAccessible::State >(__jni_env, state1);
    QAccessibleStateChangeEvent *__qt_this = new(__qtjambi_ptr) QAccessibleStateChangeEvent_shell(__qt_obj0, __qt_state1);
    Q_UNUSED(__qtjambi_is_generic)
    Q_UNUSED(__jni_object)
    Q_UNUSED(__qt_this)
}

// QAccessibleStateChangeEvent::QAccessibleStateChangeEvent(QObject*,QAccessible::State)
extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QAccessibleStateChangeEvent_initialize_1native__Lio_qt_gui_QAccessibleStateChangeEvent_2Lio_qt_core_QObject_2Lio_qt_gui_QAccessible_00024State_2)
(JNIEnv *__jni_env,
 jclass __jni_class,
 jobject __jni_object,
 jobject obj0,
 jobject state1)
{
    QTJAMBI_NATIVE_METHOD_CALL("QAccessibleStateChangeEvent::QAccessibleStateChangeEvent(QObject*,QAccessible::State)")
    QTJAMBI_TRY {
        jvalue arguments[2];
        arguments[0].l = obj0;
        arguments[1].l = state1;
        QtJambiShell::initialize(__jni_env, __jni_class, __jni_object, &__qt_construct_QAccessibleStateChangeEvent_QObject_ptr_QAccessible_State, sizeof(QAccessibleStateChangeEvent_shell), typeid(QAccessibleStateChangeEvent), true, &deleter_QAccessibleStateChangeEvent, arguments);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END

}

// destruct QAccessibleStateChangeEvent_shell
void __qt_destruct_QAccessibleStateChangeEvent(void* ptr)
{
    QTJAMBI_NATIVE_METHOD_CALL("destruct QAccessibleStateChangeEvent")
    reinterpret_cast<QAccessibleStateChangeEvent_shell*>(ptr)->~QAccessibleStateChangeEvent_shell();
}

// emitting  (functionsInTargetLang writeFinalFunction)
// QAccessibleStateChangeEvent::changedStates()const
extern "C" Q_DECL_EXPORT jobject JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QAccessibleStateChangeEvent_changedStates_1native_1constfct__J)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId)
{
    Q_UNUSED(__this)
    jobject __java_return_value{0};
    QTJAMBI_TRY {
        const QAccessibleStateChangeEvent *__qt_this = QtJambiAPI::objectFromNativeId<QAccessibleStateChangeEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        QTJAMBI_NATIVE_INSTANCE_METHOD_CALL("QAccessibleStateChangeEvent::changedStates()const", __qt_this)
        QAccessible::State __qt_return_value = __qt_this->changedStates();
        __java_return_value = qtjambi_cast<jobject>(__jni_env, __qt_return_value);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
    return __java_return_value;

}

// emitting Field accessors (writeFieldAccessors)
void QAccessibleStateChangeEvent_access::setChangedStates_cref_QAccessible_State(JNIEnv *__jni_env, QtJambiNativeID __this_nativeId, QtJambiNativeID changedStates0)
{
    Q_UNUSED(__this_nativeId)
    Q_UNUSED(__jni_env)
    const QAccessible::State& __qt_changedStates0 = QtJambiAPI::valueReferenceFromNativeId<QAccessible::State>(changedStates0);
    this->QAccessibleStateChangeEvent::m_changedStates = __qt_changedStates0;
}

extern "C" Q_DECL_EXPORT void JNICALL QTJAMBI_FUNCTION_PREFIX(Java_io_qt_gui_QAccessibleStateChangeEvent_setChangedStates_1native_1cref_1QAccessible_1State__JJ)
(JNIEnv *__jni_env,
 jobject __this,
 QtJambiNativeID __this_nativeId,
 QtJambiNativeID changedStates0)
{
    QTJAMBI_TRY {
        Q_UNUSED(__this)
        QAccessibleStateChangeEvent *__qt_this = QtJambiAPI::objectFromNativeId<QAccessibleStateChangeEvent>(__this_nativeId);
        QtJambiAPI::checkNullPointer(__jni_env, __qt_this);
        static_cast<QAccessibleStateChangeEvent_access*>(__qt_this)->setChangedStates_cref_QAccessible_State(__jni_env, __this_nativeId, changedStates0);
    }QTJAMBI_CATCH(const JavaException& exn){
        exn.raiseInJava(__jni_env);
    }QTJAMBI_TRY_END
}

// emitting (writeJavaLangObjectOverrideFunctions)

void initialize_meta_info_QAccessibleStateChangeEvent(){
    using namespace RegistryAPI;
    const std::type_info& typeId = registerObjectTypeInfo<QAccessibleStateChangeEvent>("QAccessibleStateChangeEvent", "io/qt/gui/QAccessibleStateChangeEvent");
// BEGIN: function table
    registerFunctionInfos(typeId, {
        FunctionInfo(/* 0 */ "accessibleInterface", "()Lio/qt/gui/QAccessibleInterface;")});
    registerConstructorInfos(typeId, &__qt_destruct_QAccessibleStateChangeEvent, {
        ConstructorInfo(&__qt_construct_QAccessibleStateChangeEvent_QAccessibleInterface_ptr_QAccessible_State, "Lio/qt/gui/QAccessibleInterface;Lio/qt/gui/QAccessible$State;")
       ,ConstructorInfo(&__qt_construct_QAccessibleStateChangeEvent_QObject_ptr_QAccessible_State, "Lio/qt/core/QObject;Lio/qt/gui/QAccessible$State;")
    });
// END: function table

// BEGIN: type registration
    registerDeleter(typeId, &deleter_QAccessibleStateChangeEvent);
    registerSizeOfShell(typeId, sizeof(QAccessibleStateChangeEvent_shell));
// END: type registration

// BEGIN: polymorphic ids
    registerDefaultPolymorphyHandler<QAccessibleEvent, QAccessibleStateChangeEvent>();
// END: polymorphic ids


// BEGIN: enums and flags
// END: enums and flags
}
